@@ -8,7 +8,7 @@
 # copied, modified, or distributed except according to those terms.
 """Python Library to manage NetHSM(s)."""
 
-__version__ = "1.2.1"
+__version__ = "1.4.0"
 
 import binascii
 import contextlib
@@ -19,7 +19,16 @@ from base64 import b64decode, b64encode
 from dataclasses import dataclass
 from datetime import datetime, timezone
 from io import BufferedReader, FileIO
-from typing import TYPE_CHECKING, Any, Iterator, Mapping, NoReturn, Optional, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterator,
+    Mapping,
+    NoReturn,
+    Optional,
+    Union,
+)
 from urllib.parse import urlencode
 
 import urllib3
@@ -214,14 +223,16 @@ class Base64:
         Base64(data='dGVzdAo=')
         >>> Base64.from_encoded(b"dGVzdAo=")
         Base64(data='dGVzdAo=')
-        >>> Base64.from_encoded("dGV zdAo=")
-        Traceback (most recent call last):
-            ...
-        ValueError: Invalid base64 data: Non-base64 digit found: dGV zdAo=
-        >>> Base64.from_encoded(b"dGV zdAo=")
-        Traceback (most recent call last):
-            ...
-        ValueError: Invalid base64 data: Non-base64 digit found: dGV zdAo=
+        >>> try:
+        ...     Base64.from_encoded("dGV zdAo=")
+        ...     assert False
+        ... except ValueError as e:
+        ...     assert "Invalid base64 data" in str(e)
+        >>> try:
+        ...     Base64.from_encoded(b"dGV zdAo=")
+        ...     assert False
+        ... except ValueError as e:
+        ...     assert "Invalid base64 data" in str(e)
         >>> Base64.from_encoded("dGV zdAo=", ignore_whitespace=True)
         Base64(data='dGVzdAo=')
         >>> Base64.from_encoded(b"dGV zdAo=", ignore_whitespace=True)
@@ -261,12 +272,19 @@ class Info:
     product: str
 
 
+@dataclass
+class Tpm:
+    attestation_keys: Dict[str, Any]
+    platform_configuration_registers: Dict[str, Any]
+
+
 @dataclass
 class SystemInfo:
     firmware_version: str
     software_version: str
     hardware_version: str
     build_tag: str
+    tpm: Tpm
 
 
 @dataclass
@@ -431,6 +449,7 @@ class NetHSM:
         host: str,
         auth: Optional[Authentication] = None,
         verify_tls: bool = True,
+        ca_certs: Optional[str] = None,
     ) -> None:
         from .client import ApiClient, ApiConfiguration
         from .client.components.security_schemes import security_scheme_basic
@@ -463,6 +482,7 @@ class NetHSM:
         config = ApiConfiguration(
             server_info=server_config, security_scheme_info=security_info
         )
+        config.ssl_ca_cert = ca_certs  # type: ignore[assignment]
         config.verify_ssl = verify_tls
         self.client = ApiClient(configuration=config)
 
@@ -1553,6 +1573,10 @@ class NetHSM:
             software_version=response.body.softwareVersion,
             hardware_version=response.body.hardwareVersion,
             build_tag=response.body.softwareBuild,
+            tpm=Tpm(
+                attestation_keys=dict(response.body.akPub),
+                platform_configuration_registers=dict(response.body.pcr),
+            ),
         )
 
     def backup(self) -> bytes:
